@@ -11,8 +11,8 @@
 typedef struct cpt_tree_node{
   
   double max;
-  unsigned int *index;
-  unsigned int n_intervals;
+  int *index;
+  int n_intervals;
   unsigned cpt;
   struct cpt_tree_node *left_node, *right_node;
   
@@ -20,8 +20,8 @@ typedef struct cpt_tree_node{
 
 typedef struct cpts{
   
-  unsigned int *cpt; 
-  unsigned int n_cpt;
+  int *cpt; 
+  int n_cpt;
   double min_max;
   
   cpt_tree_node_t *node;
@@ -33,20 +33,20 @@ typedef struct solution_path{
   
   cpts_t *cpts;
   double *th;
-  unsigned int n_th;
+  int n_th;
   
   
 } solution_path_t;
 
 
-void build_tree(cpt_tree_node_t **node, cpt_tree_node_t **parent_node, unsigned int start, unsigned int end,
+void build_tree(cpt_tree_node_t **node, cpt_tree_node_t **parent_node, int start, int end,
                 double th, contrasts_t *contrasts, eval_contrast_fun_t eval_contrast_fun);
-void get_changepoints(cpt_tree_node_t **node, cpts_t *cpts, unsigned int start, unsigned int end, unsigned int min_dist);
-solution_path_t *solution_path(contrasts_t *contrasts, eval_contrast_fun_t eval_contrast_fun, unsigned int min_dist);
+void get_changepoints(cpt_tree_node_t **node, cpts_t *cpts, int start, int end, int min_dist);
+solution_path_t *solution_path(contrasts_t *contrasts, eval_contrast_fun_t eval_contrast_fun, int min_dist);
 
 void destroy_tree(cpt_tree_node_t **node);
 void destroy_solution_path(solution_path_t **solution_path);
 
-int compare_cpts_t(const cpts_t *a, const cpts_t *b, unsigned int n_obs);
+int compare_cpts_t(const cpts_t *a, const cpts_t *b, int n_obs);
 
 #endif 
